# -*- coding: utf-8 -*-
"""
Created on Thu Jan 10 08:43:11 2019

@author: Staubach
"""

import numpy as np
import matplotlib.pyplot as plt
from matplotlib import cm
from matplotlib import gridspec
import os
import itertools

plt.rcParams['xtick.direction'] = 'in'
plt.rcParams['ytick.direction'] = 'in'
plt.rcParams['font.size'] = 10
plt.rcParams['text.usetex'] = True
plt.rcParams['text.color'] = 'black'
plt.rcParams['axes.spines.top'] = False
plt.rcParams['axes.spines.right'] = False
# -----------------------------------------------------------------------------
# Color definitions (RGB)
# -----------------------------------------------------------------------------
                        
# Color schemes generated with "internal" color maps          
start = 0.0
stop = 1.0
number_of_lines= 6

coolwarm = [ cm.coolwarm(x) for x in np.linspace(start, stop, number_of_lines)  ]


# -----------------------------------------------------------------------------
# Functions / Definitions
# -----------------------------------------------------------------------------
def cm2inch(*tupl):
    inch = 2.54
    if isinstance(tupl[0], tuple):
        return tuple(i/inch for i in tupl[0])
    else:
        return tuple(i/inch for i in tupl)

# -----------------------------------------------------------------------------
# Enter folder names
# -----------------------------------------------------------------------------
    
folder_list_2D = ['U8-solid-ax']
folder_list_3D = ['u20-solid','U8-solid-3d-red','U8-solid-3d-red-fine1','u4-solid-3D-fine1','u4-solid-3D']

nfolders = len(folder_list_2D) + len(folder_list_3D)

# -----------------------------------------------------------------------------
# Abq
# -----------------------------------------------------------------------------
# fname = 'path_abq.inp'
# tmp = np.loadtxt(fname, skiprows=3)
# coord_abq = tmp[:,0]
# stress_abq = -tmp[:,1]


# -----------------------------------------------------------------------------
# Plotting ranges
# -----------------------------------------------------------------------------

xmax = 60.
xmin = 0.0
ymax = 1.

# Begin figure
fig = plt.figure(figsize=cm2inch(18,9*nfolders)) 

# Set the layout of the subplots
gs = gridspec.GridSpec(nfolders,2)

# time_steps = [0.05,0.1,1,10,100,1000,10000]
# label_time_steps = ['$t = 5 \cdot10^{-2}$ s','$t = 10^{-1}$ s','$t = 10^{9}$ s',\
#                     '$t = 10^{1}$ s','$t = 10^2$ s','$t = 10^3$ s','$t = 10^4$ s']


i = 0
count = 0
file_count = 0
for name in itertools.chain(folder_list_2D,folder_list_3D):

    last_coords = []
    last_stress  = []

    last_coordsy = []
    last_stressy  = []
# =============================================================================
# Get all data files for each calculation and store them in vertical_coords and pore_pressure
# =============================================================================
    if(file_count>len(folder_list_2D)-1):
        
        for filename in os.listdir(os.getcwd()+'/'+name+ '/'+'Hertz3D-print-out'):
            stress = []
            coords = []
            if(filename[0:4] == 'SOIL'):
                stress = np.genfromtxt(os.getcwd()+'/'+name+ '/'+'Hertz3D-print-out/' + filename, skip_header=1, skip_footer=0, usecols=4)
                coords = np.genfromtxt(os.getcwd()+'/'+name+ '/'+'Hertz3D-print-out/' + filename, skip_header=1, skip_footer=0, usecols=1)
                time = np.genfromtxt(os.getcwd()+'/'+name+ '/'+'Hertz3D-print-out/' + filename, skip_header=1, skip_footer=0, usecols=0) -1.
                
                
                last_coords.append(coords[-1])
                last_stress.append(stress[-1])
            if(filename[0:4] == 'XSOI'):
                stress = np.genfromtxt(os.getcwd()+'/'+name+ '/'+'Hertz3D-print-out/' + filename, skip_header=1, skip_footer=0, usecols=4)
                coords = np.genfromtxt(os.getcwd()+'/'+name+ '/'+'Hertz3D-print-out/' + filename, skip_header=1, skip_footer=0, usecols=1)
                time = np.genfromtxt(os.getcwd()+'/'+name+ '/'+'Hertz3D-print-out/' + filename, skip_header=1, skip_footer=0, usecols=0) -1.
                
                
                last_coords.append(coords[-1])
                last_stress.append(stress[-1])
                
            if(filename[0:4] == 'YSOI'):
                stress = np.genfromtxt(os.getcwd()+'/'+name+ '/'+'Hertz3D-print-out/' + filename, skip_header=1, skip_footer=0, usecols=4)
                coords = np.genfromtxt(os.getcwd()+'/'+name+ '/'+'Hertz3D-print-out/' + filename, skip_header=1, skip_footer=0, usecols=2)
                time = np.genfromtxt(os.getcwd()+'/'+name+ '/'+'Hertz3D-print-out/' + filename, skip_header=1, skip_footer=0, usecols=0) -1.
                
                
                last_coordsy.append(coords[-1])
                last_stressy.append(stress[-1])
                
            # if(filename[0:4] == 'YSOI'):
            #     stress = np.genfromtxt(os.getcwd()+'/'+name+ '/'+'Hertz3D-print-out/' + filename, skip_header=1, skip_footer=0, usecols=4)
            #     coords = np.genfromtxt(os.getcwd()+'/'+name+ '/'+'Hertz3D-print-out/' + filename, skip_header=1, skip_footer=0, usecols=2)
            #     time = np.genfromtxt(os.getcwd()+'/'+name+ '/'+'Hertz3D-print-out/' + filename, skip_header=1, skip_footer=0, usecols=0) -1.
                
                
            #     last_coords.append(coords[-1])
            #     last_stress.append(stress[-1])
    else:
        for filename in os.listdir(os.getcwd()+'/'+name+ '/'+'hertz-print-out'):
            stress = []
            coords = []
            if(filename[0:4] == 'SOIL'):
                stress = np.genfromtxt(os.getcwd()+'/'+name+ '/'+'hertz-print-out/' + filename, skip_header=1, skip_footer=0, usecols=4)
                coords = np.genfromtxt(os.getcwd()+'/'+name+ '/'+'hertz-print-out/' + filename, skip_header=1, skip_footer=0, usecols=1)
                time = np.genfromtxt(os.getcwd()+'/'+name+ '/'+'hertz-print-out/' + filename, skip_header=1, skip_footer=0, usecols=0) -1.
            
            
                last_coords.append(coords[-1])
                last_stress.append(stress[-1])
                
    count = 0
# =============================================================================
# Now plot data for each time step for all nodes/elements along the height
# =============================================================================
    indeces = [u[0] for u in sorted(enumerate(last_coords), key=lambda x:x[1])]
    local_stress = []
    local_coords =[]
    local_coords = sorted(last_coords,reverse=False)
    for x in range(len(last_stress)):
        scalar = last_stress[indeces[x]]
        local_stress.append(scalar)
        
    if len(last_coordsy) >2:
        indecesy = [u[0] for u in sorted(enumerate(last_coordsy), key=lambda x:x[1])]
        local_stressy = []
        local_coordsy =[]
        local_coordsy = sorted(last_coordsy,reverse=False)

        for x in range(len(last_stressy)):
            scalary = last_stressy[indecesy[x]]
            local_stressy.append(scalary)
# =============================================================================
# Plot displacement
# =============================================================================
    if(file_count>len(folder_list_2D)-1):
        plt.subplot(gs[i])
        plt.title(name,fontsize=11)
        #plt.plot(coord_abq,stress_abq, color='black', linestyle='--', lw=0.75, label='abaqus contact\n pressure')
        plt.plot(local_coords,local_stress, color=coolwarm[1], lw=1.5, label='x-axis')
        if len(last_coordsy) >2:
            plt.plot(local_coordsy,local_stressy, color='r', lw=1.5, label='y-axis')
        plt.xlim(0.0,0.6)
        #plt.ylim(-7,0.)
        plt.xlabel('Distance from symmetry axis [m]' )
        plt.ylabel('Contact stress [kPa]')
        plt.legend(loc='upper right')
        #plt.grid(True)
    else:
        plt.subplot(gs[i])
        plt.title(name,fontsize=11)
        #plt.plot(coord_abq,stress_abq, color='black', linestyle='--', lw=0.75, label='abaqus contact\n pressure')
        plt.plot(local_coords,local_stress, color=coolwarm[1], lw=1.5)#, label='numgeo centroid\n vertical stress')
        plt.xlim(0.0,0.6)
        plt.locator_params(nbins=6)
        #plt.ylim(-7,0.)
        plt.xlabel('Distance from symmetry axis [m]' )
        plt.ylabel('Contact stress [kPa]')
        #plt.legend(loc='upper right')
        #plt.grid(True)
    i = i + 1
    file_count += 1


plt.tight_layout(w_pad=1.5)
plt.show()

fig.savefig('hertz_comparison.pdf', dpi=1200 , bbox_inches='tight')
fig.savefig('hertz_comparison.png', dpi=1200 , bbox_inches='tight')
#fig.savefig('terzaghi_comparison.svg', bbox_inches='tight')